==> zio-aws-dataexchange_2.13-5.17.129.2-sources.jar: zio/aws/dataexchange/model/CancelJobRequest.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class CancelJobRequest(jobId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.CancelJobRequest = {
    import CancelJobRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.CancelJobRequest
      .builder()
      .jobId(__string.unwrap(jobId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.dataexchange.model.CancelJobRequest.ReadOnly =
    zio.aws.dataexchange.model.CancelJobRequest.wrap(buildAwsValue())
}
object CancelJobRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.CancelJobRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.CancelJobRequest =
      zio.aws.dataexchange.model.CancelJobRequest(jobId)
    def jobId: __string
    def getJobId: ZIO[Any, Nothing, __string] = ZIO.succeed(jobId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.CancelJobRequest
  ) extends zio.aws.dataexchange.model.CancelJobRequest.ReadOnly {
    override val jobId: __string =
      zio.aws.dataexchange.model.primitives.__string(impl.jobId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.CancelJobRequest
  ): zio.aws.dataexchange.model.CancelJobRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-dataexchange_2.13-5.17.183.1-sources.jar: zio/aws/dataexchange/model/CancelJobRequest.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class CancelJobRequest(jobId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.CancelJobRequest = {
    import CancelJobRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.CancelJobRequest
      .builder()
      .jobId(jobId: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.dataexchange.model.CancelJobRequest.ReadOnly =
    zio.aws.dataexchange.model.CancelJobRequest.wrap(buildAwsValue())
}
object CancelJobRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.CancelJobRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.CancelJobRequest =
      zio.aws.dataexchange.model.CancelJobRequest(jobId)
    def jobId: __string
    def getJobId: ZIO[Any, Nothing, __string] = ZIO.succeed(jobId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.CancelJobRequest
  ) extends zio.aws.dataexchange.model.CancelJobRequest.ReadOnly {
    override val jobId: __string = impl.jobId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.CancelJobRequest
  ): zio.aws.dataexchange.model.CancelJobRequest.ReadOnly = new Wrapper(impl)
}
